connect 'jdbc:derby://localhost:1527/c:\derby10.1.1\OPTIM\optim;create=true';


--
-- create legacy targetdemo tables
-- schema now renamed to targetdemo
--

drop table targetdemo.details;
drop table targetdemo.items;
drop table targetdemo.orders;
drop table targetdemo.customers;
drop table targetdemo.sales;
drop table targetdemo.state;
drop table targetdemo.ship_to;
drop table targetdemo.ship_instr;
drop table targetdemo.male_rates;
drop table targetdemo.female_rates;
drop schema targetdemo restrict;


create schema targetdemo;

--table targetdemo.sales
create table targetdemo.sales
       (salesman_id       char(6)        not null,
        salesman_name     char(20)       not null,
        age               integer        not null with default 0,
        sex               char(1)        not null with default ' ',
        territory         varchar(14)    not null,
        manager_id        char(6));

--unique index targetdemo.xsalespk for table targetdemo.sales
create unique index targetdemo.xsalespk
        on targetdemo.sales
       (salesman_id       asc);

--primary key targetdemo.sales
alter table targetdemo.sales
        add primary key 
       (salesman_id);

--table targetdemo.customers
create table targetdemo.customers
       (cust_id           char(5)        not null,
        custname          char(20)       not null,
        address           varchar(50)    not null,
        city              varchar(15)    not null,
        state             char(2)        not null,
        zip               char(5),
        ytd_sales         decimal(7, 2)  not null with default 0,
        salesman_id       char(6),
        phone_number      char(10),
        nationality       varchar(30),
        national_id       varchar(30),
        creditcard_number varchar(16),
        creditcard_type   varchar(30),
        creditcard_exp    char(4),
        creditcard_cvv    varchar(4),
        email_address     varchar(50));

--unique index targetdemo.xcustpk for table targetdemo.customers
create unique index targetdemo.xcustpk
        on targetdemo.customers
       (cust_id asc);

--primary key for table targetdemo.customers
alter table targetdemo.customers
        add primary key 
       (cust_id);

--relationship rsc between targetdemo.sales and targetdemo.customers
alter table targetdemo.customers
        add constraint rsc 
        foreign key 
        (salesman_id) 
        references targetdemo.sales (salesman_id)
        on delete set null;

--table targetdemo.orders
create table targetdemo.orders
       (order_id          decimal(5, 0)  not null,
        cust_id           char(5)        not null,
        order_date        date           not null with default CURRENT_DATE,
        order_time        time           not null with default CURRENT_TIME,
        freight_charges   decimal(4, 2),
        order_salesman    char(6),
        order_posted_date timestamp      not null with default CURRENT_TIMESTAMP,
        order_ship_date   char(8)        with default null);

--unique index targetdemo.xordrpk for table targetdemo.orders
create unique index targetdemo.xordrpk
        on targetdemo.orders
       (order_id asc);

--primary key targetdemo.orders
alter table targetdemo.orders
        add primary key 
       (order_id);

--relationship rco between targetdemo.customers and targetdemo.orders
alter table targetdemo.orders
         add constraint rco
        foreign key 
       (cust_id) 
        references targetdemo.customers (cust_id)
        on delete restrict;

--table targetdemo.items
create table targetdemo.items
       (item_id           char(5)        not null,
        item_description  varchar(72)    not null,
        category          varchar(14)    not null,
        rating            char(4)        not null,
        unit_price        decimal(5, 2)  not null,
        on_hand_inventory integer        not null);

--unique index targetdemo.xitempk for table targetdemo.items
create unique index targetdemo.xitempk
        on targetdemo.items
       (item_id           asc);

--primary key targetdemo.items
alter table targetdemo.items
        add primary key 
        (item_id);

--table targetdemo.details
create table targetdemo.details
       (order_id          decimal(5, 0)  not null,
        item_id           char(5)        not null,
        item_quantity     smallint       not null,
        detail_unit_price decimal(5, 2)  not null);

--unique index targetdemo.xdetlpk for table targetdemo.details
create unique index targetdemo.xdetlpk
        on targetdemo.details
       (order_id          desc, 
        item_id           asc);

--primary key targetdemo.details
alter table targetdemo.details
        add primary key 
       (order_id, 
        item_id);

--relationship rod between targetdemo.orders and targetdemo.details
alter table targetdemo.details
         add constraint rod
        foreign key  
        (order_id) 
        references targetdemo.orders (order_id) 
        on delete cascade;

--relationship rid between targetdemo.items and targetdemo.details
alter table targetdemo.details
         add constraint rid
        foreign key  
       (item_id) 
        references targetdemo.items (item_id) 
        on delete restrict;

--table targetdemo.ship_to
create table targetdemo.ship_to
       (cust_id           char(5)        not null,
        ship_id           smallint       not null,
        address           varchar(50),
        city              varchar(15),
        state             char(2),
        zip               decimal(9, 0),
        in_care_of        varchar(30),
        shipping_change_dt date not null with default CURRENT_DATE);

--table targetdemo.female_rates
create table targetdemo.female_rates
        (age              integer,
        rate_per_1000     decimal(5, 0));

--table targetdemo.male_rates
create table targetdemo.male_rates
       (age               integer,
        rate_per_1000     decimal(5, 0));

--table targetdemo.state_lookup
create table targetdemo.state_lookup
       (district          char(2)        not null,
        dist_code         char(3)        not null);

--table targetdemo.ship_instr
create table targetdemo.ship_instr
       (ship_id           smallint,
        ship_instr_id     decimal(5, 0),
        order_ship_instr  varchar(254),
        ship_updated      timestamp      not null with default CURRENT_TIMESTAMP);

--unique index targetdemo.xshipipk for table targetdemo.ship_instr
create unique index targetdemo.xshipipk
        on targetdemo.ship_instr
        (ship_instr_id    asc);

--table targetdemo.customers2
create table targetdemo.customers2
       (cust_id           char(5)        not null,
        custname          char(20)       not null,
        address           varchar(50)    not null,
        city              varchar(15)    not null,
        state             char(2)        not null,
        zip               char(5),
        ytd_sales         decimal(7, 2)  not null with default 0,
        salesman_id       char(6),
        phone_number      char(10),
        nationality       varchar(30),
        national_id       varchar(30),
        creditcard_number varchar(16),
        creditcard_type   varchar(30),
        creditcard_exp    char(4),
        creditcard_cvv    varchar(4),
        email_address     varchar(50));

--unique index targetdemo.xcustpk2 for table targetdemo.customers2
create unique index targetdemo.xcustpk2
        on targetdemo.customers2
       (cust_id           asc);

--primary key for table targetdemo.customers2
alter table targetdemo.customers2
        add primary key 
       (cust_id);

--table targetdemo.orders2
create table targetdemo.orders2
       (order_id          decimal(5, 0)  not null,
        cust_id           char(5)        not null,
        order_date        date           not null with default CURRENT_DATE,
        order_time        time           not null with default CURRENT_TIME,
        freight_charges   decimal(4, 2),
        order_salesman    char(6),
        order_posted_date timestamp      not null with default CURRENT_TIMESTAMP,
        order_ship_date   char(8)        with default null);

--unique index targetdemo.xordrpk2 for table targetdemo.orders2
create unique index targetdemo.xordrpk2
        on targetdemo.orders2
       (order_id          asc);

--primary key targetdemo.orders2
alter table targetdemo.orders2
        add primary key 
       (order_id);
--relationship rco2 between targetdemo.customers2 and targetdemo.orders2
alter table targetdemo.orders2
         add constraint rco2
        foreign key 
       (cust_id) 
        references targetdemo.customers2 (cust_id)
        on delete restrict;

--table targetdemo.items2
create table targetdemo.items2
       (item_id           char(5)        not null,
        item_description  varchar(72)    not null,
        category          varchar(14)    not null,
        rating            char(4)        not null,
        unit_price        decimal(5, 2)  not null,
        on_hand_inventory integer        not null);

--unique index targetdemo.xitempk2 for table targetdemo.items2
create unique index targetdemo.xitempk2
        on targetdemo.items2
       (item_id           asc);

--primary key targetdemo.items2
alter table targetdemo.items2
        add primary key 
        (item_id);

--table targetdemo.details2
create table targetdemo.details2
       (order_id          decimal(5, 0)  not null,
        item_id           char(5)        not null,
        item_quantity     smallint       not null,
        detail_unit_price decimal(5, 2)  not null);

--unique index targetdemo.xdetlpk2 for table targetdemo.details2
create unique index targetdemo.xdetlpk2
        on targetdemo.details2
       (order_id          desc, 
        item_id           asc);
        
--primary key targetdemo.details2
alter table targetdemo.details2
        add primary key
       (order_id, 
        item_id);
        
--relationship rod2 between targetdemo.orders2 and targetdemo.details2
alter table targetdemo.details2
         add constraint rod2
        foreign key
        (order_id) 
        references targetdemo.orders2 (order_id)
        on delete cascade;
        
--relationship rid2 between targetdemo.items2 and targetdemo.details2
alter table targetdemo.details2
         add constraint rid2
        foreign key 
       (item_id) 
        references targetdemo.items2 (item_id)
        on delete restrict;
        
--table targetdemo.actions
create table targetdemo.actions
       (action_id            decimal(2,0)
        check ( ( ( action_id >= 0. ) and ( action_id <= 16. ) ) ),
        action_text          varchar(30),
        after_row_status     varchar(2),
        archive_desc         varchar(40),
        archive_file_name    varchar(80),
        archive_id           decimal(5,0),
        current_datetime     timestamp,
        group_name           varchar(8),
        index_file_name      varchar(80),
        machine_name         varchar(15),
        server_name          varchar(15),
        start_datetime       timestamp,
        source_tbl_dbalias   varchar(15),
        dest_tbl_dbalias     varchar(15),
        source_tbl_name      varchar(40),
        dest_tbl_name        varchar(40),
        tbl_row_in_error     decimal(9,0),
        tbl_row_processed    decimal(9,0),
        rows_left_t_b_proc   decimal(9,0),
        tbl_row_extracted    decimal(9,0),
        source_tbl_schema    varchar(20),
        dest_tbl_schema      varchar(20),
        tot_row_in_error     decimal(9,0),
        tot_row_processed    decimal(9,0),
        tot_left_t_b_proc    decimal(9,0),
        tot_proc_status      varchar(15),
        tot_row_extracted    decimal(9,0),
        user_id              varchar(8));
